<template>
    <div>
        <Category :category="category" ></Category>
    </div>
</template>
<script>
import Category from '~/components/front-end/product_category/category.vue'
import options from '~/assets/options';
export default {
  components : {Category},
      data() {
        return {
          category      : null,
          inserted_code : false,
          domain      : this.$store.state.front_end_data.domain,
        }
      },
      mounted() {
        if(this.category!=null && (!this.inserted_code)) {
          categorySelection(this.category.name);
          this.inserted_code = true;
        }
      },
     async asyncData({params,$axios,store,error}) {
          if(!store.state.front_end_data.url_available) {
          return error({ statusCode: 404, message: 'Page Not Found' })
        }
        let location = store.state.front_end_data.location;
        let current_host = store.state.front_end_data.domain_id;
        const category = await $axios.$get(`/api/category-data/${params.parent_category}/${location}/${current_host}`);
        return {category};
    },
    head() {
      if(this.category!=null) {
        return {
          title: `${(this.category.meta_title!=null) ? this.category.meta_title : this.category.name}`,
          script : [
              {
                src: '/front-end/js/google-analytics.js'
              }
            ],
          meta: [
              {
                hid: 'description',
                name: 'description',
                content: this.category.meta_description
              },
              {
                hid: 'og:title',
                name: 'og:title',
                content: this.category.meta_title
              },
              {
                hid: 'og:description',
                name: 'og:description',
                content: this.category.meta_description
              },{
                hid: 'og:type',
                name: 'og:type',
                content: "Website"
              },
              {
                hid: 'og:url',
                name: 'og:url',
                content: this.domain.url + this.$route.fullPath
              },
              {
                hid: 'og:url',
                name: 'og:site_name',
                content: this.domain.name
              },
              {
                hid: 'og:image',
                name: 'og:image',
                content: this.category.og_image_url
              },
              {
                hid: 'name',
                name: 'twitter:card',
                content: "summary_large_image"
              },
              {
                hid: 'name',
                name: 'twitter:title',
                content: this.category.meta_title
              },
              {
                hid: 'name',
                name: 'twitter:description',
                content: this.category.meta_description
              },
              {
                hid: 'name',
                name: 'twitter:image:src',
                content: this.category.og_image_url
              },
              {
                hid: 'name',
                name: 'twitter:site',
                content: this.domain.name
              },
            ],
          }
        }
    },
}
</script>